Documentation
¶
Index ¶
- Constants
- Variables
- func AcceptedAmount(v float64) predicate.Bid
- func AcceptedAmountEQ(v float64) predicate.Bid
- func AcceptedAmountGT(v float64) predicate.Bid
- func AcceptedAmountGTE(v float64) predicate.Bid
- func AcceptedAmountIn(vs ...float64) predicate.Bid
- func AcceptedAmountLT(v float64) predicate.Bid
- func AcceptedAmountLTE(v float64) predicate.Bid
- func AcceptedAmountNEQ(v float64) predicate.Bid
- func AcceptedAmountNotIn(vs ...float64) predicate.Bid
- func Amount(v float64) predicate.Bid
- func AmountEQ(v float64) predicate.Bid
- func AmountGT(v float64) predicate.Bid
- func AmountGTE(v float64) predicate.Bid
- func AmountIn(vs ...float64) predicate.Bid
- func AmountLT(v float64) predicate.Bid
- func AmountLTE(v float64) predicate.Bid
- func AmountNEQ(v float64) predicate.Bid
- func AmountNotIn(vs ...float64) predicate.Bid
- func And(predicates ...predicate.Bid) predicate.Bid
- func CreatedAt(v time.Time) predicate.Bid
- func CreatedAtEQ(v time.Time) predicate.Bid
- func CreatedAtGT(v time.Time) predicate.Bid
- func CreatedAtGTE(v time.Time) predicate.Bid
- func CreatedAtIn(vs ...time.Time) predicate.Bid
- func CreatedAtLT(v time.Time) predicate.Bid
- func CreatedAtLTE(v time.Time) predicate.Bid
- func CreatedAtNEQ(v time.Time) predicate.Bid
- func CreatedAtNotIn(vs ...time.Time) predicate.Bid
- func HasInvestor() predicate.Bid
- func HasInvestorWith(preds ...predicate.Investor) predicate.Bid
- func HasInvoice() predicate.Bid
- func HasInvoiceWith(preds ...predicate.Invoice) predicate.Bid
- func ID(id uuid.UUID) predicate.Bid
- func IDEQ(id uuid.UUID) predicate.Bid
- func IDGT(id uuid.UUID) predicate.Bid
- func IDGTE(id uuid.UUID) predicate.Bid
- func IDIn(ids ...uuid.UUID) predicate.Bid
- func IDLT(id uuid.UUID) predicate.Bid
- func IDLTE(id uuid.UUID) predicate.Bid
- func IDNEQ(id uuid.UUID) predicate.Bid
- func IDNotIn(ids ...uuid.UUID) predicate.Bid
- func Not(p predicate.Bid) predicate.Bid
- func Or(predicates ...predicate.Bid) predicate.Bid
- func StatusEQ(v Status) predicate.Bid
- func StatusIn(vs ...Status) predicate.Bid
- func StatusNEQ(v Status) predicate.Bid
- func StatusNotIn(vs ...Status) predicate.Bid
- func StatusValidator(s Status) error
- func UpdatedAt(v time.Time) predicate.Bid
- func UpdatedAtEQ(v time.Time) predicate.Bid
- func UpdatedAtGT(v time.Time) predicate.Bid
- func UpdatedAtGTE(v time.Time) predicate.Bid
- func UpdatedAtIn(vs ...time.Time) predicate.Bid
- func UpdatedAtLT(v time.Time) predicate.Bid
- func UpdatedAtLTE(v time.Time) predicate.Bid
- func UpdatedAtNEQ(v time.Time) predicate.Bid
- func UpdatedAtNotIn(vs ...time.Time) predicate.Bid
- func ValidColumn(column string) bool
- type OrderOption
- func ByAcceptedAmount(opts ...sql.OrderTermOption) OrderOption
- func ByAmount(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByInvestorField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByInvoiceField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- type Status
Constants ¶
const ( // Label holds the string label denoting the bid type in the database. Label = "bid" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldAmount holds the string denoting the amount field in the database. FieldAmount = "amount" // FieldAcceptedAmount holds the string denoting the accepted_amount field in the database. FieldAcceptedAmount = "accepted_amount" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeInvoice holds the string denoting the invoice edge name in mutations. EdgeInvoice = "invoice" // EdgeInvestor holds the string denoting the investor edge name in mutations. EdgeInvestor = "investor" // Table holds the table name of the bid in the database. Table = "bids" // InvoiceTable is the table that holds the invoice relation/edge. InvoiceTable = "bids" // InvoiceInverseTable is the table name for the Invoice entity. // It exists in this package in order to avoid circular dependency with the "invoice" package. InvoiceInverseTable = "invoices" // InvoiceColumn is the table column denoting the invoice relation/edge. InvoiceColumn = "invoice_bids" // InvestorTable is the table that holds the investor relation/edge. InvestorTable = "bids" // InvestorInverseTable is the table name for the Investor entity. // It exists in this package in order to avoid circular dependency with the "investor" package. InvestorInverseTable = "investors" // InvestorColumn is the table column denoting the investor relation/edge. InvestorColumn = "investor_bids" )
const DefaultStatus = StatusPENDING
StatusPENDING is the default value of the Status enum.
Variables ¶
var ( // DefaultAcceptedAmount holds the default value on creation for the "accepted_amount" field. DefaultAcceptedAmount float64 // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldStatus, FieldAmount, FieldAcceptedAmount, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for bid fields.
var ForeignKeys = []string{
"investor_bids",
"invoice_bids",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "bids" table and are not defined as standalone fields in the schema.
Functions ¶
func AcceptedAmount ¶
AcceptedAmount applies equality check predicate on the "accepted_amount" field. It's identical to AcceptedAmountEQ.
func AcceptedAmountEQ ¶
AcceptedAmountEQ applies the EQ predicate on the "accepted_amount" field.
func AcceptedAmountGT ¶
AcceptedAmountGT applies the GT predicate on the "accepted_amount" field.
func AcceptedAmountGTE ¶
AcceptedAmountGTE applies the GTE predicate on the "accepted_amount" field.
func AcceptedAmountIn ¶
AcceptedAmountIn applies the In predicate on the "accepted_amount" field.
func AcceptedAmountLT ¶
AcceptedAmountLT applies the LT predicate on the "accepted_amount" field.
func AcceptedAmountLTE ¶
AcceptedAmountLTE applies the LTE predicate on the "accepted_amount" field.
func AcceptedAmountNEQ ¶
AcceptedAmountNEQ applies the NEQ predicate on the "accepted_amount" field.
func AcceptedAmountNotIn ¶
AcceptedAmountNotIn applies the NotIn predicate on the "accepted_amount" field.
func Amount ¶
Amount applies equality check predicate on the "amount" field. It's identical to AmountEQ.
func AmountNotIn ¶
AmountNotIn applies the NotIn predicate on the "amount" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasInvestor ¶
HasInvestor applies the HasEdge predicate on the "investor" edge.
func HasInvestorWith ¶
HasInvestorWith applies the HasEdge predicate on the "investor" edge with a given conditions (other predicates).
func HasInvoice ¶
HasInvoice applies the HasEdge predicate on the "invoice" edge.
func HasInvoiceWith ¶
HasInvoiceWith applies the HasEdge predicate on the "invoice" edge with a given conditions (other predicates).
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Bid queries.
func ByAcceptedAmount ¶
func ByAcceptedAmount(opts ...sql.OrderTermOption) OrderOption
ByAcceptedAmount orders the results by the accepted_amount field.
func ByAmount ¶
func ByAmount(opts ...sql.OrderTermOption) OrderOption
ByAmount orders the results by the amount field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByInvestorField ¶
func ByInvestorField(field string, opts ...sql.OrderTermOption) OrderOption
ByInvestorField orders the results by investor field.
func ByInvoiceField ¶
func ByInvoiceField(field string, opts ...sql.OrderTermOption) OrderOption
ByInvoiceField orders the results by invoice field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.